@@ -7,8 +7,9 @@ import json
 import socket
 import os.path
 import shutil
-from processor.helper.config.config_utils import config_value, framework_currentdata, get_cache_data, set_cache_data, TESTS, DBTESTS, DBVALUES, SNAPSHOT, SINGLETEST
-from processor.helper.json.json_utils import json_from_file, save_json_to_file,get_container_dir
+from processor.helper.config.config_utils import config_value, framework_currentdata, get_cache_data, \
+    set_cache_data, TESTS, DBTESTS, DBVALUES, SNAPSHOT
+from processor.helper.json.json_utils import json_from_file, save_json_to_file
 from processor.logging.log_handler import getlogger, FWLOGFILENAME
 from processor.helper.file.file_utils import remove_file, exists_dir, mkdir_path
 
@@ -126,11 +127,11 @@ def save_currentdata(curr_data):
 def delete_currentdata():
     """Delete the rundata file when exiting of the script."""
     logger = getlogger()
-    singletest = get_from_currentdata(SINGLETEST)
-    if singletest:
-        container = get_from_currentdata('container')
-        cdir = get_container_dir(container)
-        shutil.rmtree('%s/snapshots' % cdir)
+    # singletest = get_from_currentdata(SINGLETEST)
+    # if singletest:
+    #     container = get_from_currentdata('container')
+    #     cdir = get_container_dir(container)
+    #     shutil.rmtree('%s/snapshots' % cdir)
 
     cleaning_repos = get_from_currentdata("CLEANING_REPOS")
     if cleaning_repos:
